Learn R Programming

metaviz (version 0.4.0)

viz_tlma_studyinfo: A dataframe containing information on the study effects of a three-level meta-analysis

Description

Provides a dataframe with information on the study effects of a three-level meta-analysis.

Usage

viz_tlma_studyinfo(x, confidence_level_ci = 0.95, ordered = FALSE)

Value

A dataframe containing statistical information about the study effects of a three-level meta-analysis is created.

Arguments

x

metafor rma.mv object

confidence_level_ci

numeric confidence level for the confidence intervals of the study effects

ordered

orders the data by effect size when TRUE

Author

Verena Pilar <[email protected]>

Details

The function viz_tlma_studyinfo creates a dataframe with information pertaining to the study effects of a three-level meta-analysis. The study effects are the result of random-effects models conducted on the effects contained within each respective study. The dataframe contains the number of effects originating from the study, the study effect with its standard error and confidence intervals, and the weight of the study within the three-level meta-analysis.

Examples

Run this code

if (requireNamespace("psymetadata", quietly = TRUE)) {
  # Get wibbelink2017 data
  testdata <- psymetadata::wibbelink2017


  # Calculate the three-level meta-analytic model
  testmodel <- metafor::rma.mv(yi,
                              vi,
                              random = ~ 1 | study_id/es_id,
                              tdist = TRUE,
                              data = testdata,
                              method = "REML")

  # Create a table with study-level information
  viz_tlma_studyinfo(testmodel)
}

Run the code above in your browser using DataLab