The package metaviz is a collection of functions for creating visually
appealing and information-rich plots of meta-analytic data using ggplot2.
Functions are provided for creating several variants of forest plots
(viz_forest), funnel plots (viz_funnel, viz_sunset),
conducting visual inference with funnel plots (funnelinf), visualizing
three-level meta-analyses (viz_tlma_forest, viz_tlma_studyinfo),
and comparing fixed-effect and random-effects models
(wineq_forest, wineq_gini, wineq_baujat).
Several different types and variants of forest plots can be created with
viz_forest. These include classic forest plots, subgroup forest plots,
cumulative summary forest plots, and leave-one-out sensitivity forest plots.
In addition, the function allows users to individually label and color studies
and to align tables with further study-level and summary-level information.
In addition to traditional forest plots, rainforest plots and thick forest plots
can be used. Rainforest and thick forest plots are two proposed variants and
enhancements of the classic forest plot. Both variants visually emphasize large
studies (with short confidence intervals and more weight in the meta-analysis),
while small studies (with wide confidence intervals and less weight in the
meta-analysis) are visually less dominant. For further details see
help(viz_forest), help(viz_rainforest), and
help(viz_thickforest).
Dedicated visualizations for three-level meta-analysis are provided by
viz_tlma_forest and viz_tlma_studyinfo. The function
viz_tlma_forest creates forest plots specifically designed to visualize
the hierarchical structure of effect sizes nested within studies in three-level
meta-analysis. The function viz_tlma_studyinfo provides a complementary
visualization of study-level information and the distribution of effect sizes
across studies. For further details see help(viz_tlma_forest) and
help(viz_tlma_studyinfo).
Numerous different funnel plot variants can be created. Options for several
graphical augmentations (e.g., confidence, significance, and additional evidence
contours; choice of the ordinate; showing study subgroups) and different types
of statistical information are provided, including Egger's regression line,
imputed studies from the trim-and-fill method, and the corresponding adjusted
summary effect. Further details and references can be found in the corresponding
help file (help(viz_funnel)).
Moreover, a novel variant of the funnel plot is provided that displays the power
of studies to detect an effect of interest (e.g., the meta-analytic summary effect)
using a two-sided Wald test. This sunset (power-enhanced) funnel plot uses
color-coded regions and a second y-axis to visualize study-level power and can
help to critically examine the evidentiality and credibility of a set of studies.
For further details see help(viz_sunset).
Funnel plots are widely used in meta-analysis to assess small-study effects as
potential indicators of publication bias. Visual inference can help to improve
the objectivity and validity of conclusions based on funnel plot examinations by
guarding the meta-analyst against interpreting patterns in the funnel plot that
might be perfectly plausible by chance. Only if the funnel plot showing the real
data is distinguishable from simultaneously presented null funnel plots showing
data simulated under the null hypothesis might conclusions based on visual
inspection of the real-data funnel plot be warranted. The function
funnelinf provides numerous tailored options for conducting visual
inference with funnel plots in the context of meta-analysis. See
help(funnelinf) for further details and relevant references.
Wineq plots provide graphical tools for comparing fixed-effect and random-effects meta-analysis models based on the same data. The plots highlight how the choice between the two models affects study weights, the concentration of study weights, the influence of individual studies, and the resulting overall effect.
Three complementary visualization functions are available. The function
wineq_forest integrates study weights and overall effects from both models
into a single forest plot and visualizes changes in study weights between the
fixed-effect and random-effects model. Classic, thick, and rainforest plot
variants are available. The function wineq_gini compares the concentration
of study weights between the two models using Lorenz curves and corresponding
Gini indices. The function wineq_baujat extends the traditional Baujat
plot by visualizing the direction and magnitude of changes in the influence of
individual studies on the overall effect between the fixed-effect and
random-effects model. For further details see help(wineq_forest),
help(wineq_gini), and help(wineq_baujat).
Four different example datasets from published meta-analyses are distributed with the package:
Two datasets for meta-analyses with standardized mean differences
(mozart, homeopath)
One dataset for a meta-analysis with correlation coefficients
(brainvol)
One dataset for a meta-analysis with dichotomous outcome data
(exrehab)
More details and corresponding references can be found in the respective help
files (help(mozart), help(homeopath), help(brainvol),
help(exrehab)).
Maintainer: Michael Kossmeier [email protected]
Authors:
Michael Kossmeier [email protected]
Ulrich S. Tran [email protected]
Martin Voracek [email protected]
Verena Pilar [email protected]
Useful links: