- x
metafor rma.uni object conducted with method “FE” or “REML” (the chosen method of the input model makes
no difference in the resulting plot)
- group
factor indicating the group membership of each study
- variant
“classic” (default), “thick” or “rain” to create a classic, thick or rainforest plot variant
- method
determines whether x-axis values are based on the fixed-effect (“FE”) or the random-effects model
(“REML”; default). If no value is entered, the method is extracted from model x.
- study_labels
y-axis labels for the study effects
- summary_label_FE
y-axis label for the fixed-effect model summary effect
- summary_label_REML
y-axis label for the random-effects model summary effect
- confidence_level
confidence level for the study effects and summary effects
- summary_line
adds dashed vertical lines intersecting each summary effect
- summary_col_FE
determines color of the fixed-effect model summary effect
- summary_col_REML
determines color of the random-effects model summary effect
- col
“weights”: colors point estimates (classic variant), errorbars (thick variant) or raindrops (rain variant)
according to weight change on a gradient from blue to red, “BW”: greyscale version, Note: the rain variant is only available in color)
- errorbar_col
boolean argument that determines whether the errorbars of the classic variant are colored
according to weight change (“TRUE”) or in black (“FALSE”)
- text_size
determines text size within the plot
- xlab
x-axis label
- x_limit
determines the limits of the x-axis. Input is a numeric vector of length 2 (min, max).
- x_trans_function
function which transforms x-axis labels back to their original scale when data consists,
for example, of log-odds-ratios or Fisher’s z values
- x_breaks
option to costumize the number of breaks on the x-axis. Input is a numeric vector specifying the breaks
- annotate_CI
adds a right-hand side table to the plot containing the confidence intervals of each effect
- study_table
custom table on the left-hand side of the plot that contains study information. Takes a dataframe
as input which has to be of a length equal to the number of studies.
- summary_table
custom table on the left-hand side of the plot that contains information about the summary
effects. Takes a dataframe as input which contains one row for each summary effect.
- table_headers
headers for each column of the left-hand side table. Takes a character vector as input
- table_layout
numeric layout matrix to customize the arrangement of the plot and tables
- show_legend
shows a color legend below the plot which corresponds to the change in weight between the fixed and random-effects model
- ...
further arguments passed to the internal helper functions for the classic, thick and rainforest variants of the wineq forest plot